macro_rules! __admin_api_endpoint {
(
$path:expr_2021,
$version_introduced:expr_2021,
async |$state:ident: &$state_ty:ty, $context:ident, $auth:ident, $param:ident: $param_ty:ty| -> $resp_ty:ty $body:block
) => { ... };
(
$path:expr_2021,
$version_introduced:expr_2021,
async |$state:ident: &$state_ty:ty, $context:ident, $param:ident: $param_ty:ty| -> $resp_ty:ty $body:block
) => { ... };
}Expand description
Declares an API endpoint that verifies guardian authentication before entering the handler body.
An optional token argument between the context and request binds the
verified GuardianAuthToken for
handlers that pass the proof of authentication to privileged inner
functions.